@@ -3,7 +3,6 @@ package httpclient
 import (
 	"context"
 	"crypto/tls"
-	"io"
 	"net"
 	"net/http"
 	neturl "net/url"
@@ -11,6 +10,8 @@ import (
 	"time"
 
 	"github.com/lmorg/murex/config"
+	"github.com/lmorg/murex/lang"
+	"github.com/lmorg/murex/lang/stdio"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/utils/json"
 )
@@ -23,7 +24,7 @@ const (
 var rxHttpProto = regexp.MustCompile(`(?i)^http(s)?://`)
 
 // Request generates a HTTP request
-func Request(ctx context.Context, method, url string, body io.Reader, conf *config.Config, setTimeout bool) (response *http.Response, err error) {
+func Request(ctx context.Context, method, url string, body stdio.Io, conf *config.Config, setTimeout bool) (response *http.Response, err error) {
 	toStr, err := conf.Get("http", "timeout", types.String)
 	if err != nil {
 		return
@@ -41,7 +42,7 @@ func Request(ctx context.Context, method, url string, body io.Reader, conf *conf
 	var client *http.Client
 	if setTimeout {
 		tr := http.Transport{
-			Dial:            dialTimeout(toDur, toDur, conf),
+			Dial:            dialTimeout(toDur, toDur),
 			TLSClientConfig: &tls.Config{InsecureSkipVerify: insecure.(bool)},
 		}
 
@@ -77,6 +78,10 @@ func Request(ctx context.Context, method, url string, body io.Reader, conf *conf
 		return
 	}
 
+	if body != nil {
+		request.Header.Add("Content-Type", lang.MurexToMime(body.GetDataType()))
+	}
+
 	// code in meta functions
 	setHeaders(request, conf, &urlParsed.Host)
 	setCookies(request, conf, &urlParsed.Host)
@@ -101,7 +106,7 @@ func Request(ctx context.Context, method, url string, body io.Reader, conf *conf
 
 // dialTimeout function unashamedly copy and pasted from:
 // https://stackoverflow.com/questions/16895294/how-to-set-timeout-for-http-get-requests-in-golang#16930649
-func dialTimeout(cTimeout time.Duration, rwTimeout time.Duration, conf *config.Config) func(net, addr string) (c net.Conn, err error) {
+func dialTimeout(cTimeout time.Duration, rwTimeout time.Duration) func(net, addr string) (c net.Conn, err error) {
 	return func(netw, addr string) (net.Conn, error) {
 		conn, err := net.DialTimeout(netw, addr, cTimeout)
 		if err != nil {
