@@ -5,16 +5,14 @@ package lang
 
 import (
 	"github.com/lmorg/murex/builtins/pipes/streams"
-	"github.com/lmorg/murex/lang/tty"
 	"github.com/lmorg/murex/lang/types"
 )
 
 func ttys(p *Process) {
-	p.ttyin = tty.Stdin
+	if p.CCExists != nil && p.CCExists(p.Name.String()) {
+		p.Stderr, p.CCErr = streams.NewTee(p.Stderr)
+		p.CCErr.SetDataType(types.Generic)
 
-	p.Stdout, p.CCOut = streams.NewTee(p.Stdout)
-	p.ttyout = tty.Stdout
-
-	p.Stderr, p.CCErr = streams.NewTee(p.Stderr)
-	p.CCErr.SetDataType(types.Generic)
+		p.Stdout, p.CCOut = streams.NewTee(p.Stdout)
+	}
 }
