@@ -1,10 +1,14 @@
 //go:build !js
 // +build !js
 
+//go:generate go build -v golang.org/x/tools/cmd/stringer
+
 package main
 
 import (
+	"flag"
 	"os"
+	"strings"
 	"time"
 
 	_ "github.com/lmorg/murex/builtins"
@@ -16,14 +20,10 @@ import (
 	"github.com/lmorg/murex/lang/ref"
 	"github.com/lmorg/murex/shell"
 	"github.com/lmorg/murex/utils/cache"
+	"github.com/lmorg/murex/utils/escape"
 	"github.com/lmorg/murex/utils/readline"
 )
 
-const (
-	interactive    bool = true
-	nonInteractive bool = false
-)
-
 func main() {
 	readFlags()
 
@@ -32,13 +32,16 @@ func main() {
 		runTests()
 
 	case fCommand != "":
-		runCommandLine(fCommand)
+		runCommandString(fCommand)
+
+	case fExecute:
+		runCommandString(argvToCmdLineStr(flag.Args()))
 
 	case len(fSource) > 0:
 		runSource(fSource[0])
 
 	default:
-		startMurex()
+		startMurexRepl()
 	}
 
 	debug.Log("[FIN]")
@@ -47,8 +50,8 @@ func main() {
 func runTests() error {
 	lang.InitEnv()
 
-	defaults.Config(lang.ShellProcess.Config, nonInteractive)
-	shell.SignalHandler(nonInteractive)
+	defaults.Config(lang.ShellProcess.Config, fInteractive)
+	registerSignalHandlers(fInteractive)
 
 	// compiled profile
 	defaultProfile()
@@ -79,12 +82,19 @@ func runTests() error {
 	return nil
 }
 
-func runCommandLine(commandLine string) {
+func argvToCmdLineStr(argv []string) string {
+	cmdLine := make([]string, len(argv))
+	copy(cmdLine, argv)
+	escape.CommandLine(cmdLine)
+	return strings.Join(cmdLine, " ")
+}
+
+func runCommandString(commandString string) {
 	lang.InitEnv()
 
 	// default config
-	defaults.Config(lang.ShellProcess.Config, nonInteractive)
-	shell.SignalHandler(nonInteractive)
+	defaults.Config(lang.ShellProcess.Config, fInteractive)
+	registerSignalHandlers(fInteractive)
 
 	// compiled profile
 	defaultProfile()
@@ -101,7 +111,7 @@ func runCommandLine(commandLine string) {
 		Filename: "",
 		Module:   "murex/-c",
 	}
-	execSource([]rune(commandLine), &sourceRef, true)
+	execSource([]rune(commandString), &sourceRef, true)
 
 	if fInteractive {
 		shell.Start()
@@ -112,8 +122,8 @@ func runSource(filename string) {
 	lang.InitEnv()
 
 	// default config
-	defaults.Config(lang.ShellProcess.Config, nonInteractive)
-	shell.SignalHandler(nonInteractive)
+	defaults.Config(lang.ShellProcess.Config, fInteractive)
+	registerSignalHandlers(fInteractive)
 
 	// compiled profile
 	defaultProfile()
@@ -144,11 +154,11 @@ func runSource(filename string) {
 	execSource([]rune(string(disk)), &sourceRef, true)
 }
 
-func startMurex() {
+func startMurexRepl() {
 	lang.InitEnv()
 
 	// default config
-	defaults.Config(lang.ShellProcess.Config, interactive)
+	defaults.Config(lang.ShellProcess.Config, true)
 
 	cache.SetPath(profile.ModulePath() + "cache.db")
 	cache.InitCache()
@@ -160,5 +170,6 @@ func startMurex() {
 	profile.Execute(profile.F_PRELOAD | profile.F_MODULES | profile.F_PROFILE)
 
 	// start interactive shell
+	registerSignalHandlers(true)
 	shell.Start()
 }
