@@ -13,12 +13,13 @@ func DynamicPreview(previewBlock string, exe string, params []string) readline.P
 	block := []rune(previewBlock)
 
 	return func(ctx context.Context, line []rune, item string, _ bool, size *readline.PreviewSizeT, callback readline.PreviewFuncCallbackT) {
-		hash := cache.CreateHash(exe, params, block)
+		hash := cache.CreateHash(string(line), block)
+
 		var b []byte
 
 		if !cache.Read(cache.PREVIEW_DYNAMIC, hash, &b) {
 
-			fork := lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_BACKGROUND | lang.F_NO_STDIN | lang.F_CREATE_STDOUT | lang.F_NO_STDERR)
+			fork := lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_BACKGROUND | lang.F_NO_STDIN | lang.F_CREATE_STDOUT | lang.F_CREATE_STDERR)
 			fork.Name.Set(exe)
 			fork.Parameters.DefineParsed(params)
 			fork.FileRef = autocomplete.ExesFlagsFileRef[exe]
@@ -37,6 +38,14 @@ func DynamicPreview(previewBlock string, exe string, params []string) readline.P
 				return
 			}
 
+			e, err := fork.Stderr.ReadAll()
+			if err != nil {
+				s, _, err := previewError(err, size)
+				callback(s, 0, err)
+				return
+			}
+			b = append(b, e...)
+
 			ttl := autocomplete.ExesFlags[exe][0].CacheTTL
 			cache.Write(cache.PREVIEW_DYNAMIC, hash, &b, cache.Seconds(ttl))
 		}
